@@ -175,7 +175,7 @@ class Worker(Background):
         finally:
             self.greenlet_group.kill()
             for sockets in self._cached_reply_sockets.viewvalues():
-                for socket in sockets.viewvalues():
+                for socket in sockets.values():
                     socket.close()
             self._cached_reply_sockets.clear()
 
